@@ -1,3 +1,4 @@
+import datetime
 from typing import Sequence, Callable, Optional, Any, Dict, TYPE_CHECKING
 
 from datacode.logger import logger
@@ -70,7 +71,7 @@ class AnalysisOptions(OperationOptions):
     def __init__(self, func: Callable[[DataSource, Any], Any],
                  output_func: Optional[Callable[['AnalysisResult', str], None]] = analysis_result_to_file,
                  out_path: Optional[str] = None, result_kwargs: Optional[Dict[str, Any]] = None,
-                 always_rerun: bool = False,
+                 always_rerun: bool = False, last_modified: Optional[datetime.datetime] = None,
                  **func_kwargs):
         """
 
@@ -79,6 +80,7 @@ class AnalysisOptions(OperationOptions):
         :param out_path:
         :param result_kwargs:
         :param always_rerun: Whether to re-run operation if executed multiple times
+        :param last_modified: manually override last modified
         :param func_kwargs:
         """
         self.func = func
@@ -86,6 +88,7 @@ class AnalysisOptions(OperationOptions):
         self.analysis_output_func = output_func
         self.out_path = out_path
         self.result_kwargs = result_kwargs
+        self.last_modified = last_modified
         self.always_rerun = always_rerun
 
     @property
